@@ -10,8 +10,8 @@ my $cv = AE::cv();
 
 my $redis = AnyEvent::Redis::RipeRedis->new(
   host     => 'localhost',
-  port     => '6379',
-  password => 'yourpass',
+  port     => 6379,
+  password => 'redis_pass',
 
   on_connect => sub {
     print "Connected to Redis server\n";
