@@ -10,11 +10,12 @@ my $cv = AE::cv();
 
 my $redis;
 $redis = AnyEvent::Redis::RipeRedis->new(
-  host               => 'unix/',
-  port               => '/var/run/redis/redis.sock',
-  password           => 'yourpass',
-  connection_timeout => 5,
-  read_timeout       => 5,
+  host                   => 'unix/',
+  port                   => '/var/run/redis/redis.sock',
+  password               => 'redis_pass',
+  connection_timeout     => 5,
+  read_timeout           => 5,
+  min_reconnect_interval => 5,
 
   on_connect => sub {
     print "Connected to Redis server\n";
